from uuid import UUID

import fastapi

from .schemas import (
    TaskBaseSchema, TaskPostSchema, TaskPatchSchema,
    CommentSchema
)
from .ctrl import TaskController


router = fastapi.APIRouter(prefix='/tasks', tags=['Task'])
ctrl = TaskController()


@router.get('')
async def get_tasks(
    title: str | None = None,
    status: str | None = None,
    priority: str | None = None
):
    return await ctrl.get_list(title=title, status=status, priority=priority)


@router.get('/{id}')
async def get_task(id: UUID):
    return await ctrl.get(id)


@router.post('')
async def create_task(body: TaskPostSchema):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_task(id: UUID, body: TaskPatchSchema):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_task(id: UUID):
    return await ctrl.delete(id)


@router.get('/{id}/comments')
async def get_comments(id: UUID):
    return await ctrl.get_comments(id)


@router.post('/{id}/comments')
async def add_comment(id: UUID, body: CommentSchema):
    return await ctrl.add_comment(id, **body.model_dump(exclude_none=True))


@router.delete('/comments/{id}')
async def delete_comment(id: UUID):
    return await ctrl.delete_comment(id)


@router.get('/tasks/search')
async def search_tasks(keywords: str):
    return await ctrl.search(keywords)
